@@ -59,6 +59,8 @@ static const char* scan_brightness()
 		return "/sys/devices/virtual/backlight/acpi_video0/brightness";
         if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight.0/backlight/pcf50633-backlight/brightness"))
                 return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight.0/backlight/pcf50633-backlight/brightness";
+        if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight/backlight/pcf50633-backlight/brightness"))
+                return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight/backlight/pcf50633-backlight/brightness";
 	return NULL;
 }
 static const char* scan_max_brightness()
@@ -70,6 +72,8 @@ static const char* scan_max_brightness()
 		return "/sys/devices/virtual/backlight/acpi_video0/max_brightness";
         if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight.0/backlight/pcf50633-backlight/max_brightness"))
                 return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight.0/backlight/pcf50633-backlight/max_brightness";
+        if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight/backlight/pcf50633-backlight/max_brightness"))
+                return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight/backlight/pcf50633-backlight/max_brightness";
 	return NULL;
 }
 static const char* scan_actual_brightness()
@@ -80,6 +84,8 @@ static const char* scan_actual_brightness()
 		return "/sys/devices/virtual/backlight/acpi_video0/actual_brightness";
         if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight.0/backlight/pcf50633-backlight/actual_brightness"))
                 return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight.0/backlight/pcf50633-backlight/actual_brightness";
+        if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight/backlight/pcf50633-backlight/actual_brightness"))
+                return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-backlight/backlight/pcf50633-backlight/actual_brightness";
 	return NULL;
 }
 static const char* scan_chg_curlim()
@@ -88,6 +94,20 @@ static const char* scan_chg_curlim()
 		return "/sys/class/i2c-adapter/i2c-0/0-0073/pcf50633-mbc/chg_curlim";
 	if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-mbc/chg_curlim"))
 		return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-mbc/chg_curlim";
+        if (exists("/sys/bus/platform/devices/pcf50633-mbc/chg_curlim"))
+		return "/sys/bus/platform/devices/pcf50633-mbc/chg_curlim";
+        if (exists("/sys/bus/platform/devices/pcf50633-mbc.0/chg_curlim"))
+		return "/sys/bus/platform/devices/pcf50633-mbc.0/chg_curlim";
+	return NULL;
+}
+static const char* scan_usb_curlim()
+{
+	if (exists("/sys/class/i2c-adapter/i2c-0/0-0073/pcf50633-mbc/usb_curlim"))
+		return "/sys/class/i2c-adapter/i2c-0/0-0073/pcf50633-mbc/usb_curlim";
+	if (exists("/sys/bus/platform/devices/pcf50633-mbc.0/usb_curlim"))
+		return "/sys/bus/platform/devices/pcf50633-mbc.0/usb_curlim";
+	if (exists("/sys/bus/platform/devices/pcf50633-mbc/usb_curlim"))
+		return "/sys/bus/platform/devices/pcf50633-mbc/usb_curlim";
 	return NULL;
 }
 static const char* scan_resume_reason()
@@ -95,6 +115,8 @@ static const char* scan_resume_reason()
 	// TODO return \"$(find /sys -wholename "*neo1973-resume.0/resume_reason")\"
 	if (exists("/sys/class/i2c-adapter/i2c-0/0-0073/neo1973-resume.0/resume_reason"))
 		return "/sys/class/i2c-adapter/i2c-0/0-0073/neo1973-resume.0/resume_reason";
+	if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/neo1973-resume.0/resume_reason"))
+		return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/neo1973-resume.0/resume_reason";
 	return NULL;
 }
 static const char* scan_resume_reason2()
@@ -102,6 +124,8 @@ static const char* scan_resume_reason2()
 	// TODO return \"$(find /sys -wholename "*/0-0073/resume_reason")\"
 	if (exists("/sys/class/i2c-adapter/i2c-0/0-0073/resume_reason"))
 		return "/sys/class/i2c-adapter/i2c-0/0-0073/resume_reason";
+	if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/resume_reason"))
+		return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/resume_reason";
 	return NULL;
 }
 static const char* scan_pm_bt()
@@ -109,6 +133,8 @@ static const char* scan_pm_bt()
 	// TODO return \"$(find /sys -wholename "*pm-bt*/power_on" -o -wholename "*pm-bt*/pwron")\"
 	if (exists("/sys/class/i2c-adapter/i2c-0/0-0073/pcf50633-regltr.6/neo1973-pm-bt.0"))
 		return "/sys/class/i2c-adapter/i2c-0/0-0073/pcf50633-regltr.6/neo1973-pm-bt.0";
+	if (exists("/sys/devices/platform/gta02-pm-bt.0"))
+		return "/sys/devices/platform/gta02-pm-bt.0";
 	return NULL;
 }
 static const char* scan_pm_gps()
@@ -118,6 +144,8 @@ static const char* scan_pm_gps()
 		return "/sys/class/i2c-adapter/i2c-0/0-0073/pcf50633-regltr.7/neo1973-pm-gps.0";
 	if (exists("/sys/class/i2c-adapter/i2c-0/0-0073/pcf50633-regltr.7/gta02-pm-gps.0"))
 		return "/sys/class/i2c-adapter/i2c-0/0-0073/pcf50633-regltr.7/gta02-pm-gps.0";
+	if (exists("/sys/devices/platform/gta02-pm-gps.0"))
+		return "/sys/devices/platform/gta02-pm-gps.0";
 	return NULL;
 }
 static const char* scan_pm_gsm()
@@ -128,6 +156,8 @@ static const char* scan_pm_gsm()
 		return "/sys/class/i2c-adapter/i2c-0/0-0073/neo1973-pm-gsm.0";
 	if (exists("/sys/class/i2c-adapter/i2c-0/0-0073/gta02-pm-gsm.0"))
 		return "/sys/class/i2c-adapter/i2c-0/0-0073/gta02-pm-gsm.0";
+        if (exists("/sys/bus/platform/devices/gta02-pm-gsm.0"))
+		return "/sys/bus/platform/devices/gta02-pm-gsm.0";
 	return NULL;
 }
 static const char* scan_pm_wlan()
@@ -138,6 +168,51 @@ static const char* scan_pm_wlan()
 	return NULL;
 }
 
+static const char* scan_screen_resolution()
+{
+	if (exists("/sys/devices/platform/s3c2440-i2c/i2c-adapter/i2c-0/0-0073/pcf50633-regltr.9/glamo3362.0/glamo-spi-gpio.0/spi2.0/state"))
+		return "/sys/devices/platform/s3c2440-i2c/i2c-adapter/i2c-0/0-0073/pcf50633-regltr.9/glamo3362.0/glamo-spi-gpio.0/spi2.0/state";
+	return NULL;
+}
+
+static const char* scan_screen_resolution2()
+{
+        if (exists("/sys/class/lcd/jbt6k74-lcd/device/resolution"))
+		return "/sys/class/lcd/jbt6k74-lcd/device/resolution";
+	return NULL;
+}
+
+static const char* scan_usb_charger_mode()
+{
+	if (exists("/sys/class/i2c-adapter/i2c-0/0-0073/neo1973-pm-host.0/hostmode"))
+		return "/sys/class/i2c-adapter/i2c-0/0-0073/neo1973-pm-host.0/hostmode";
+	if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-gpio/reg-fixed-voltage.2/gta02-pm-usbhost.0/power_on"))
+		return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-gpio/reg-fixed-voltage.2/gta02-pm-usbhost.0/power_on";
+        if (exists("/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-gpio.0/reg-fixed-voltage.2/gta02-pm-usbhost.0/power_on"))
+		return "/sys/devices/platform/s3c2440-i2c/i2c-0/0-0073/pcf50633-gpio.0/reg-fixed-voltage.2/gta02-pm-usbhost.0/power_on";
+	return NULL;
+}
+
+static const char* scan_usb_mode()
+{
+	// TODO sys_usb_mode=\"$(find /sys -name usb_mode)\"
+
+	if (exists("/sys/devices/platform/s3c-ohci/usb_mode"))
+		return "/sys/devices/platform/s3c-ohci/usb_mode";
+	if (exists("/sys/devices/platform/s3c2410-ohci/usb_mode"))
+		return "/sys/devices/platform/s3c2410-ohci/usb_mode";
+	return NULL;
+}
+
+static const char* scan_wifi_root()
+{
+	if (exists("/sys/bus/platform/drivers/s3c2440-sdi"))
+		return "/sys/bus/platform/drivers/s3c2440-sdi";
+	if (exists("/sys/bus/platform/drivers/s3c-sdi"))
+		return "/sys/bus/platform/drivers/s3c-sdi";
+	return NULL;
+}
+
 static struct om_sysfs_name om_sysfs_names[] = {
 	{ "actual_brightness", scan_actual_brightness, NULL },
 	{ "battery", scan_battery, NULL },
@@ -152,7 +227,12 @@ static struct om_sysfs_name om_sysfs_names[] = {
 	{ "pm-wlan", scan_pm_wlan, NULL },
 	{ "resume_reason", scan_resume_reason, NULL },
 	{ "resume_reason2", scan_resume_reason2, NULL },
-// TODO sys_usb_mode=\"$(find /sys -name usb_mode)\"
+	{ "screen_resolution", scan_screen_resolution, NULL },
+	{ "screen_resolution2", scan_screen_resolution2, NULL },
+	{ "usb_charger_mode", scan_usb_charger_mode, NULL },
+	{ "usb_curlim", scan_usb_curlim, NULL },
+	{ "usb_mode", scan_usb_mode, NULL },
+	{ "wifi_root", scan_wifi_root, NULL },
 };
 static const int om_sysfs_names_size = sizeof(om_sysfs_names) / sizeof(om_sysfs_names[0]);
 
@@ -201,7 +281,7 @@ const char* om_sysfs_readfile(const char* pathname)
 
 cleanup:
 	if (fd >= 0) close(fd);
-	return buf;
+	return res;
 }
 
 int om_sysfs_writefile(const char* pathname, const char* str)
@@ -215,7 +295,6 @@ int om_sysfs_writefile(const char* pathname, const char* str)
 	count = write(fd, str, ssize);
 	if (count != ssize)
 		res = count;
-//cleaup:
 	if (fd >= 0) close(fd);
 	return res;
 }
@@ -230,6 +309,7 @@ const char* om_sysfs_get(const char* name)
 int om_sysfs_set(const char* name, const char* val)
 {
 	const char* path = om_sysfs_path(name);
+	if (path == NULL) return -1;
 	return om_sysfs_writefile(path, val);
 }
 
