@@ -83,11 +83,32 @@ int do_sysfs(int argc, char *const *argv)
 
 void usage_backlight(FILE* out)
 {
+	fprintf(out, "%s %s backlight brightness [0-100]\n", usage_lead(), argv0);
 	fprintf(out, "%s %s backlight\n", usage_lead(), argv0);
 	fprintf(out, "%s %s backlight get-max\n", usage_lead(), argv0);
 	fprintf(out, "%s %s backlight <brightness>\n", usage_lead(), argv0);
 }
 
+static int fixpoint_new(int x) {
+    return x * 256;
+}
+
+static int fixpoint_return(int x) {
+    return x / 256;
+}
+
+static int fixpoint_mul(int a, int b) {
+    return (a * b) / 256;
+}
+
+static int fixpoint_div(int a, int b) {
+    return (a * 256) / b;
+}
+
+static int fixpoint_round(int x) {
+    return (x + 128) & ~0xff;
+}
+
 int do_backlight(int argc, char *const *argv)
 {
 	if (argc == 1)
@@ -111,6 +132,55 @@ int do_backlight(int argc, char *const *argv)
 				return 1;
 			}
 			printf("%d\n", val);
+		} else if (strcmp(argv[1], "brightness") == 0)
+		{
+			int max = om_screen_brightness_get_max();
+			if (max < 0)
+			{
+				perror("getting max brightness value");
+				return 1;
+			}
+			if (argc == 2)
+			{
+				int val = om_screen_brightness_get();
+				if (val < 0)
+				{
+					perror("getting brightness");
+					return 1;
+				}
+				printf("%d\n",
+				       fixpoint_return(fixpoint_round(
+							       fixpoint_div(fixpoint_mul(fixpoint_new(val),
+											 fixpoint_new(100)),
+									    fixpoint_new(max)))));
+			} else if (opts.swap) {
+				int old_val = om_screen_brightness_swap(
+					fixpoint_return(fixpoint_round(
+								fixpoint_div(fixpoint_mul(fixpoint_new(atoi(argv[2])),
+											  fixpoint_new(max)),
+									     fixpoint_new(100)))));
+				if (old_val < 0)
+				{
+					perror("getting/setting brightness");
+					return 1;
+				}
+				printf("%d\n",
+				       fixpoint_return(fixpoint_round(
+							       fixpoint_div(fixpoint_mul(fixpoint_new(old_val),
+											 fixpoint_new(100)),
+									    fixpoint_new(max)))));
+			} else {
+				int res = om_screen_brightness_set(
+					fixpoint_return(fixpoint_round(
+								fixpoint_div(fixpoint_mul(fixpoint_new(atoi(argv[2])),
+											  fixpoint_new(max)),
+									     fixpoint_new(100)))));
+				if (res < 0)
+				{
+					perror("setting brightness");
+					return 1;
+				}
+			}
 		} else if (opts.swap) {
 			int old_val = om_screen_brightness_swap(atoi(argv[1]));
 			if (old_val < 0)
@@ -134,6 +204,8 @@ int do_backlight(int argc, char *const *argv)
 void usage_screen(FILE* out)
 {
 	fprintf(out, "%s %s screen power [1/0]\n", usage_lead(), argv0);
+	fprintf(out, "%s %s screen resolution [normal|qvga-normal]\n", usage_lead(), argv0);
+	fprintf(out, "%s %s screen glamo-bus-timings [4-4-4|2-4-2]\n", usage_lead(), argv0);
 }
 
 int do_screen(int argc, char *const *argv)
@@ -162,6 +234,42 @@ int do_screen(int argc, char *const *argv)
 				return 1;
 			}
 		}
+	} else if (strcmp(argv[1], "resolution") == 0) {
+		if (argc == 2)
+		{
+			const char* res = om_screen_resolution_get();
+			if (res == NULL)
+			{
+				perror("reading screen resolution");
+				return 1;
+			}
+			puts(res);
+		} else {
+			int res = om_screen_resolution_set(argv[2]);
+			if (res < 0)
+			{
+				perror("setting screen resolution");
+				return 1;
+			}
+		}
+	} else if (strcmp(argv[1], "glamo-bus-timings") == 0) {
+		if (argc == 2)
+		{
+			const char* res = om_screen_glamo_bus_timings_get();
+			if (res == NULL)
+			{
+				perror("reading screen glamo bus timings");
+				return 1;
+			}
+			puts(res);
+		} else {
+			int res = om_screen_glamo_bus_timings_set(argv[2]);
+			if (res < 0)
+			{
+				perror("setting screen glamo bus timings");
+				return 1;
+			}
+		}
 	} else {
 		usage_screen(stderr);
 		return 1;
